from unittest.mock import sentinel

from django_g import get_current_request
from django_g.middleware import RequestMiddleware


def test_middleware(mocker):
    middleware = RequestMiddleware(None)
    middleware.process_request(sentinel.request)
    assert get_current_request() == sentinel.request



from typing import Optional

from django.http import HttpRequest

from . import local


def set_request(request: HttpRequest):
    local._HTTP_REQUEST_VAR.set(request)


def get_current_request() -> Optional[HttpRequest]:
    return local._HTTP_REQUEST_VAR.get()



from django.http import HttpRequest

import django_g


class RequestMiddleware:
    def __init__(self, get_response):
        self.get_response = get_response

    def process_request(self, request: HttpRequest) -> None:
        django_g.set_request(request)



from setuptools import find_packages, setup

setup(
    packages=find_packages(),
    include_package_data=True,
    install_requires=[
        "django",
    ],
    setup_requires=[
        "pytest-runner",
    ],
    tests_require=[
        "pytest",
        "pytest-black",
        "pytest-cov",
        "pytest-mock",
    ],
)
